==> istio-model-v1alpha3-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPFaultInjectionAbortHttpStatusFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPFaultInjectionAbortHttpStatusFluent<A extends HTTPFaultInjectionAbortHttpStatusFluent<A>> extends BaseFluent<A>{
  public HTTPFaultInjectionAbortHttpStatusFluent() {
  }
  public HTTPFaultInjectionAbortHttpStatusFluent(HTTPFaultInjectionAbortHttpStatus instance) {
    instance = (instance != null ? instance : new HTTPFaultInjectionAbortHttpStatus());

    if (instance != null) {
      this.withHttpStatus(instance.getHttpStatus());
      this.withHttpStatus(instance.getHttpStatus());
    }
  }
  private Integer httpStatus;
  public Integer getHttpStatus() {
    return this.httpStatus;
  }
  public A withHttpStatus(Integer httpStatus) {
    this.httpStatus=httpStatus; return (A) this;
  }
  public boolean hasHttpStatus() {
    return this.httpStatus != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPFaultInjectionAbortHttpStatusFluent that = (HTTPFaultInjectionAbortHttpStatusFluent) o;
    if (!java.util.Objects.equals(httpStatus, that.httpStatus)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpStatus,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (httpStatus != null) { sb.append("httpStatus:"); sb.append(httpStatus); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPFaultInjectionAbortHttpStatusFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class HTTPFaultInjectionAbortHttpStatusFluent<A extends HTTPFaultInjectionAbortHttpStatusFluent<A>> extends BaseFluent<A>{
  public HTTPFaultInjectionAbortHttpStatusFluent() {
  }
  
  public HTTPFaultInjectionAbortHttpStatusFluent(HTTPFaultInjectionAbortHttpStatus instance) {
    this.copyInstance(instance);
  }
  private Integer httpStatus;
  
  protected void copyInstance(HTTPFaultInjectionAbortHttpStatus instance) {
    instance = (instance != null ? instance : new HTTPFaultInjectionAbortHttpStatus());
  
    if (instance != null) {
        this.withHttpStatus(instance.getHttpStatus());
        this.withHttpStatus(instance.getHttpStatus());
      }
  }
  
  public Integer getHttpStatus() {
    return this.httpStatus;
  }
  
  public A withHttpStatus(Integer httpStatus) {
    this.httpStatus=httpStatus; return (A) this;
  }
  
  public boolean hasHttpStatus() {
    return this.httpStatus != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPFaultInjectionAbortHttpStatusFluent that = (HTTPFaultInjectionAbortHttpStatusFluent) o;
    if (!java.util.Objects.equals(httpStatus, that.httpStatus)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(httpStatus,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (httpStatus != null) { sb.append("httpStatus:"); sb.append(httpStatus); }
    sb.append("}");
    return sb.toString();
  }
  

}
